/*
 *  The ManaPlus Client
 *  Copyright (C) 2004-2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011-2017  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef GUI_WIDGETS_LINKHANDLER_H
#define GUI_WIDGETS_LINKHANDLER_H

#include <string>

#include "listeners/mouselistener.h"

/**
 * A simple interface to windows that need to handle links from BrowserBox
 * widget.
 */
class LinkHandler notfinal
{
    public:
        LinkHandler()
        { }

        A_DELETE_COPY(LinkHandler)

        virtual ~LinkHandler()
        { }

        virtual void handleLink(const std::string &link,
                                MouseEvent *event) = 0;
};

#endif  // GUI_WIDGETS_LINKHANDLER_H
